# Collection: {{COLLECTION_NAME}}

*Collections are custom lists for specific topics, projects, or trackers*

## Purpose
*What is this collection for?*


## Items

-
-
-


## Notes


---

**Common Collection Ideas:**
- Books to Read
- Movies to Watch
- Gift Ideas
- Travel Plans
- Recipes to Try
- Gratitude Log
- Meal Planning
- Budget Tracker
- Exercise Log
- Sleep Tracker
- Mood Tracker
- Ideas & Inspiration
- Quotes I Love

*Create collections as you need them. Reference them in your index.*
